imaplib.readonly

Module imaplib :: Class readonly |
[show private | hide private]
[frames | no frames]

## Class readonly

    Exception --+
                |
            error --+
                    |
                abort --+
                        |
                       readonly

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:53 2005 | http://epydoc.sf.net